from app.scripts import BaseMigrationScript

import os
import app.defaults

#
# In 17.1, /etc/sourceforge.properties was removed. However, any repositories
# created before 17.1 still contain hook scripts that refer to
# /etc/sourceforge.properties -- these need to be updated.
#

OLD_TOKEN = "SOURCEFORGE_PROPERTIES_PATH='/etc/sourceforge.properties'"
NEW_TOKEN = "SOURCEFORGE_PROPERTIES_PATH='%s/conf/integration.properties'" % app.defaults.DEFAULT_RUNTIME_DIR

class MigrationScript(BaseMigrationScript):
    scriptDescription = "Update hooks to use integration.properties"

    def __getSvnHooks(self, base):
        hooks = []
        if os.path.isdir(base):
            for repo in os.listdir(base):
                for hookType in ["pre-commit", "post-commit", "pre-revprop-change", "post-revprop-change"]:
                    hook = os.path.join(base, repo, "hooks", hookType)
                    if os.path.isfile(hook):
                        hooks.append(hook)
        return hooks

    def __getCvsHooks(self, base):
        hooks = []
        for repo in os.listdir(base):
            for hookType in ["verifymsg", "loginfo", "commitinfo"]:
                hook = os.path.join(base, repo, "CVSROOT", hookType)
                if os.path.isfile(hook):
                    hooks.append(hook)
        return hooks

    def __migrateHooks(self, hookFiles):
        for hookFile in hookFiles:
            self.log.debug("Migrating hook %s..." % hookFile)
            with open(hookFile, "r") as f:
                hookContent = f.read()

            with open(hookFile, "w") as f:
                f.write(hookContent.replace(OLD_TOKEN, NEW_TOKEN))

    def migrate(self):

        if self.cfg.has_key("SUBVERSION_BRANDING_REPOSITORY_BASE") and self.cfg["SUBVERSION_BRANDING_REPOSITORY_BASE"] != "":
            self.log.info("Migrating internal SVN hooks...")
            self.__migrateHooks(self.__getSvnHooks(self.cfg['SUBVERSION_BRANDING_REPOSITORY_BASE']))

        if self.cfg.has_key("SUBVERSION_REPOSITORY_BASE") and self.cfg["SUBVERSION_REPOSITORY_BASE"] != "":
            self.log.info("Migrating SVN hooks...")
            self.__migrateHooks(self.__getSvnHooks(self.cfg['SUBVERSION_REPOSITORY_BASE']))

        if self.cfg.has_key("CVS_REPOSITORY_BASE") and self.cfg["CVS_REPOSITORY_BASE"] != "":
            self.log.info("Migrating CVS hooks...")
            self.__migrateHooks(self.__getCvsHooks(self.cfg['CVS_REPOSITORY_BASE']))
