﻿import os
import app.servicecontrol
import app.defaults
import app.health
import app.threaddump

class ServiceController(app.servicecontrol.SimpleDaemonController):
    def getPidFile(self):
        return os.path.join(app.defaults.DEFAULT_RUN_DIR, "integration.pid")

    def __getInitScript(self):
        return os.path.join(app.defaults.DEFAULT_SERVICE_DIR, "integration", "bin", "catalina.sh")

    def getCommand(self):
        return "%s run" % self.__getInitScript()

    def stopDaemonAsync(self):
        return os.system("%s stop < /dev/null >> %s 2>&1 &" % (
            self.__getInitScript(),
            self.getServiceLogPath())) == 0

    def printSnapshot(self, label):
        config = app.util.getRuntimeConfiguration()
        integrationFile = os.path.join(config['INTEGRATION_LOG_DIR'], 'catalina.out')
        integrationPid = self.getPid()
        app.threaddump.ThreadDump.dumpJVMthread(integrationPid, self.logger, integrationFile, "integration", label)
        if integrationPid is not None:
            print "integration JVM threads dumped to %s." %integrationFile
            print "Find thread dump between lines from log demarked by - %s"%label

    def isHealthy(self):
        #
        # We directly invoke the Tomcat endpoint (not via Apache). This is okay
        # as Apache has its own health check. Also, it avoids trouble with self-
        # signed SSL certificates.
        #
        tomcatHttpEndpoint = self.getService().getProvidedEndpoint("http-soap")

        url = "http://localhost:%d/integration/health?verbose=true&thorough=false" % \
            (tomcatHttpEndpoint.getPort())

        return app.health.HealthCheck("Integration", url, self.logger).invoke()
    
    def getLogPaths(self):
        return [os.path.join(app.util.getRuntimeConfiguration().get("INTEGRATION_LOG_DIR"), "*")]
