import os
import app.servicecontrol
import app.defaults

# Set to True for detailed, per-path indexing log output; set to False
# for summary and warning/error information only.
VERBOSE_OUTPUT_MODE = False

class ServiceController(app.servicecontrol.SimpleDaemonController):
    def getCommand(self):
        cmd = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                           '..', 'bin', 'svn-index-repositories')
        return "%s%s >> %s 2>&1" % (cmd,
                                    VERBOSE_OUTPUT_MODE and ' --verbose' or '',
                                    self.getServiceLogPath())

    def __isDisabled(self):
        # This machine is marked as offline, so let is not do anything.
        return os.path.isfile(app.defaults.OFFLINE_MARKER)

    def startDaemonAsync(self):
        if self.__isDisabled():
            # This machine is marked as offline, so let is not do anything.
            self.logger.info("Skipping indexer execution as machine is marked offline")
            return True

        else:
            self.logger.info("Launching indexer")
            return super(ServiceController, self).startDaemonAsync()

    def isDemandStart(self):
        # When the service starts, it does its indexing and then it terminates. To do another
        # round of indexing, it needs to be started again.
        return True
